@@ -15,6 +15,7 @@
 
 #include <CalendarSupport/CalPrinter>
 
+#include <Akonadi/CalendarUtils>
 #include <Akonadi/EntityTreeModel>
 
 #include <QVBoxLayout>
@@ -58,14 +59,14 @@ KOTodoView::KOTodoView(bool sidebarView, QWidget *parent)
 
     connect(mView, qOverload<>(&EventViews::TodoView::newEventSignal), this, qOverload<>(&KOTodoView::newEventSignal));
 
-    connect(mView, qOverload<const QDate &>(&EventViews::TodoView::newEventSignal),
-            this, qOverload<const QDate &>(&KOTodoView::newEventSignal));
+    connect(mView, qOverload<const QDate &>(&EventViews::TodoView::newEventSignal), this, qOverload<const QDate &>(&KOTodoView::newEventSignal));
 
-    connect(mView, qOverload<const QDateTime &>(&EventViews::TodoView::newEventSignal),
-            this, qOverload<const QDateTime &>(&KOTodoView::newEventSignal));
+    connect(mView, qOverload<const QDateTime &>(&EventViews::TodoView::newEventSignal), this, qOverload<const QDateTime &>(&KOTodoView::newEventSignal));
 
-    connect(mView, qOverload<const QDateTime &, const QDateTime &>(&EventViews::TodoView::newEventSignal),
-            this, qOverload<const QDateTime &, const QDateTime &>(&KOTodoView::newEventSignal));
+    connect(mView,
+            qOverload<const QDateTime &, const QDateTime &>(&EventViews::TodoView::newEventSignal),
+            this,
+            qOverload<const QDateTime &, const QDateTime &>(&KOTodoView::newEventSignal));
 
     connect(mView, &EventViews::EventView::newTodoSignal, this, &BaseView::newTodoSignal);
 
@@ -161,7 +162,7 @@ void KOTodoView::printTodo(bool preview)
     }
 
     Akonadi::Item todoItem = selectedItems.first();
-    KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
+    KCalendarCore::Todo::Ptr todo = Akonadi::CalendarUtils::todo(todoItem);
     Q_ASSERT(todo);
 
     CalendarSupport::CalPrinter printer(this, calendar(), true);
